@@ -1,14 +1,16 @@
 # -----------------------------------------------------------------------------
 # Description:    Utilities for handling data.
 # Repository:     https://gitlab.com/quantify-os/quantify-core
-# Copyright (C) Qblox BV & Orange Quantum Systems Holding BV (2020)
+# Copyright (C) Qblox BV & Orange Quantum Systems Holding BV (2020-2021)
 # -----------------------------------------------------------------------------
-import pathlib
 import os
 import sys
 import json
+from dateutil.parser import parse
+from typing import Union
+from collections import OrderedDict
 from collections.abc import Iterable
-from datetime import datetime
+import datetime
 from uuid import uuid4
 import numpy as np
 import xarray as xr
@@ -22,18 +24,16 @@ from quantify.utilities.general import (
 # this is a pointer to the module object instance itself.
 this = sys.modules[__name__]
 
-_default_datadir = pathlib.Path(__file__).parent.parent.parent.absolute() / "data"
-
 this._datadir = None
 
 
-def gen_tuid(ts=None):
+def gen_tuid(ts: datetime.datetime = None) -> TUID:
     """
     Generates a :class:`~quantify.data.types.TUID` based on current time.
 
     Parameters
     ----------
-    ts : :class:`datetime.datetime`
+    ts: :class:`~datetime.datetime`
         optional, can be passed to ensure the tuid is based on a specific time.
 
     Returns
@@ -42,11 +42,11 @@ def gen_tuid(ts=None):
         timestamp based uid.
     """
     if ts is None:
-        ts = datetime.now()
+        ts = datetime.datetime.now()
     # ts gives microsecs by default
     (dt, micro) = ts.strftime("%Y%m%d-%H%M%S-.%f").split(".")
     # this ensures the string is formatted correctly as some systems return 0 for micro
-    dt = "%s%03d-" % (dt, int(micro) / 1000)
+    dt = f"{dt}{int(int(micro) / 1000):03d}-"
     # the tuid is composed of the timestamp and a 6 character uuid.
     tuid = TUID(dt + str(uuid4())[:6])
 
@@ -63,14 +63,23 @@ def get_datadir():
     str
         the current data directory
     """
+    set_datadir_import = "from " + this.__name__ + " import set_datadir"
 
-    if this._datadir is None:
-        this._datadir = this._default_datadir
+    if this._datadir is None or not os.path.isdir(this._datadir):
+        raise NotADirectoryError(
+            "The datadir is not valid. Please set the datadir after importing Quantify.\n"
+            "We recommend to settle for a single common data directory for all \n"
+            "notebooks/experiments within your measurement setup/PC.\n"
+            "E.g. '~/quantify-data' (unix), or 'D:\\Data\\quantify-data' (Windows).\n"
+            "The datadir can be changed as follows:\n\n"
+            f"    {set_datadir_import}\n"
+            "    set_datadir('path_to_datadir')"
+        )
 
     return this._datadir
 
 
-def set_datadir(datadir: str):
+def set_datadir(datadir: str) -> None:
     """
     Sets the data directory.
 
@@ -79,6 +88,8 @@ def set_datadir(datadir: str):
     datadir : str
             path of the data directory. If set to ``None``, resets the datadir to the default datadir (``<top_level>/data``).
     """
+    if not os.path.isdir(datadir):
+        os.mkdir(datadir)
     this._datadir = datadir
 
 
@@ -92,7 +103,7 @@ def _locate_experiment_file(tuid: TUID, datadir: str, name: str) -> str:
     exp_folders = list(filter(lambda x: tuid in x, os.listdir(daydir)))
     if len(exp_folders) == 0:
         print(os.listdir(daydir))
-        raise FileNotFoundError("File with tuid: {} was not found.".format(tuid))
+        raise FileNotFoundError(f"File with tuid: {tuid} was not found.")
 
     # We assume that the length is 1 as tuid is assumed to be unique
     exp_folder = exp_folders[0]
@@ -188,7 +199,7 @@ def create_exp_folder(tuid: TUID, name: str = "", datadir=None):
     return exp_folder
 
 
-def initialize_dataset(settable_pars, setpoints, gettable_pars):
+def initialize_dataset(settable_pars: list, setpoints: list, gettable_pars: list):
     """
     Initialize an empty dataset based on settable_pars, setpoints and gettable_pars
 
@@ -210,11 +221,11 @@ def initialize_dataset(settable_pars, setpoints, gettable_pars):
         darrs.append(
             xr.DataArray(
                 data=setpoints[:, i],
-                name="x{}".format(i),
+                name=f"x{i}",
                 attrs={
                     "name": setpar.name,
                     "long_name": setpar.label,
-                    "unit": setpar.unit,
+                    "units": setpar.unit,
                 },
             )
         )
@@ -236,8 +247,8 @@ def initialize_dataset(settable_pars, setpoints, gettable_pars):
             darrs.append(
                 xr.DataArray(
                     data=empty_arr,
-                    name="y{}".format(j + idx),
-                    attrs={"name": info[0], "long_name": info[1], "unit": info[2]},
+                    name=f"y{j + idx}",
+                    attrs={"name": info[0], "long_name": info[1], "units": info[2]},
                 )
             )
             count += 1
@@ -248,7 +259,7 @@ def initialize_dataset(settable_pars, setpoints, gettable_pars):
     return dataset
 
 
-def grow_dataset(dataset: xr.Dataset):
+def grow_dataset(dataset: xr.Dataset) -> xr.Dataset:
     """
     Resizes the dataset by doubling the current length of all arrays.
 
@@ -276,7 +287,7 @@ def grow_dataset(dataset: xr.Dataset):
     return dataset.merge(new_data)
 
 
-def trim_dataset(dataset: xr.Dataset):
+def trim_dataset(dataset: xr.Dataset) -> xr.Dataset:
     """
     Trim NaNs from a dataset, useful in the case of a dynamically resized dataset (eg. adaptive loops).
 
@@ -331,14 +342,16 @@ def get_latest_tuid(contains: str = "") -> TUID:
     FileNotFoundError
         No data found
     """
-    return get_tuids_containing(contains, max_results=1)[0]
+    # `max_results=1, reverse=True` makes sure the tuid is found efficiently asap
+    return get_tuids_containing(contains, max_results=1, reverse=True)[0]
 
 
 def get_tuids_containing(
     contains: str,
-    t_start: datetime.date = None,
-    t_stop: datetime.date = None,
+    t_start: Union[datetime.datetime, str] = None,
+    t_stop: Union[datetime.datetime, str] = None,
     max_results: int = sys.maxsize,
+    reverse: bool = False,
 ) -> list:
     """
     Returns a list of tuids containing a specific label.
@@ -350,14 +363,20 @@ def get_tuids_containing(
 
     Parameters
     ----------
-    contains : str
+    contains
         a string contained in the experiment name.
-    t_start : datetime.date
-        date to search from, inclusive.
-    t_stop : datetime.date
-        date to search until, exclusive.
-    max_results : int
+    t_start
+        datetime to search from, inclusive. If a string is specified, it will be
+        converted to a datetime object using :func:`dateutil.parser.parse`.
+        If no value is specified, will use the year 1 as a reference t_start.
+    t_stop
+        datetime to search until, exclusive. If a string is specified, it will be
+        converted to a datetime object using :func:`dateutil.parser.parse`.
+        If no value is specified, will use the current time as a reference t_stop.
+    max_results
         maximum number of results to return. Defaults to unlimited.
+    reverse
+        if False, sorts tuids chronologically, if True sorts by most recent.
     Returns
     -------
     list
@@ -368,10 +387,24 @@ def get_tuids_containing(
         No data found
     """
     datadir = get_datadir()
+    if isinstance(t_start, str):
+        t_start = parse(t_start)
+    elif t_start is None:
+        t_start = datetime.datetime(1, 1, 1)
+    if isinstance(t_stop, str):
+        t_stop = parse(t_stop)
+    elif t_stop is None:
+        t_stop = datetime.datetime.now()
 
     # date range filters, define here to make the next line more readable
-    lower_bound = lambda x: x >= t_start if t_start else True  # noqa: E731
-    upper_bound = lambda x: x < t_stop if t_stop else True  # noqa: E731
+    d_start = t_start.strftime("%Y%m%d")
+    d_stop = t_stop.strftime("%Y%m%d")
+
+    def lower_bound(x):
+        return x >= d_start if d_start else True  # noqa: E731
+
+    def upper_bound(x):
+        return x <= d_stop if d_stop else True  # noqa: E731
 
     daydirs = list(
         filter(
@@ -381,41 +414,43 @@ def get_tuids_containing(
             os.listdir(datadir),
         )
     )
-    daydirs.sort(reverse=True)
+    daydirs.sort(reverse=reverse)
     if len(daydirs) == 0:
-        err_msg = 'There are no valid day directories in the data folder "{}"'.format(
-            datadir
-        )
+        err_msg = f"There are no valid day directories in the data folder '{datadir}'"
         if t_start or t_stop:
-            err_msg += ", for the range {}-{}".format(t_start or "", t_stop or "")
+            err_msg += f", for the range {t_start or ''} to {t_stop or ''}"
         raise FileNotFoundError(err_msg)
 
     tuids = []
     for dd in daydirs:
         expdirs = list(
             filter(
-                lambda x: (len(x) > 25 and TUID.is_valid(x[:26]) and contains in x),
+                lambda x: (
+                    len(x) > 25
+                    and TUID.is_valid(x[:26])  # tuid is valid
+                    and (contains in x)  # label is part of exp_name
+                    and (t_start <= parse(x[:15]))  # tuid is after t_start
+                    and (parse(x[:15]) < t_stop)  # tuid is before t_stop
+                ),
                 os.listdir(os.path.join(datadir, dd)),
             )
         )
-        expdirs.sort(reverse=True)
+        expdirs.sort(reverse=reverse)
         for expname in expdirs:
             # Check for inconsistent folder structure for datasets portability
             if dd != expname[:8]:
                 raise FileNotFoundError(
-                    'Experiment container "{}" is in wrong day directory "{}" '.format(
-                        expname, dd
-                    )
+                    f"Experiment container '{expname}' is in wrong day directory '{dd}'"
                 )
             tuids.append(TUID(expname[:26]))
             if len(tuids) == max_results:
                 return tuids
     if len(tuids) == 0:
-        raise FileNotFoundError('No experiment found containing "{}"'.format(contains))
+        raise FileNotFoundError(f"No experiment found containing '{contains}'")
     return tuids
 
 
-def snapshot(update: bool = False, clean: bool = True) -> dict:
+def snapshot(update: bool = False, clean: bool = True) -> OrderedDict:
     """
     State of all instruments setup as a JSON-compatible dictionary (everything that the custom JSON encoder class
     :class:`qcodes.utils.helpers.NumpyJSONEncoder` supports).
@@ -428,10 +463,12 @@ def snapshot(update: bool = False, clean: bool = True) -> dict:
         if True, removes certain keys from the snapshot to create a more readable and compact snapshot.
     """
 
-    snap = {
-        "instruments": {},
-        "parameters": {},
-    }
+    snap = OrderedDict(
+        {
+            "instruments": {},
+            "parameters": {},
+        }
+    )
     for ins_name, ins_ref in Instrument._all_instruments.items():
         snap["instruments"][ins_name] = ins_ref().snapshot(update=update)
 
@@ -455,6 +492,10 @@ def snapshot(update: bool = False, clean: bool = True) -> dict:
 
 
 # ######################################################################
+# Private utilities
+# ######################################################################
+
+
 def _xi_and_yi_match(dsets: Iterable) -> bool:
     """
     Checks if all xi and yi data variables in `dsets` match:
@@ -479,7 +520,9 @@ def _vars_match(dsets: Iterable, var_type="x") -> bool:
     def get_xi_attrs(dset):
         # Hash is used in order to ensure everything matches:
         # name, long_name, unit, number of xi
-        return tuple(dset[xi].attrs for xi in sorted(get_keys_containing(dset, var_type)))
+        return tuple(
+            dset[xi].attrs for xi in sorted(get_keys_containing(dset, var_type))
+        )
 
     it = map(get_xi_attrs, dsets)
     # We can compare to the first one always
