@@ -1,4 +1,4 @@
 from .control import MeasurementControl
 from .types import Settable, Gettable
 
-__all__ = ['MeasurementControl', 'Settable', 'Gettable']
+__all__ = ["MeasurementControl", "Settable", "Gettable"]
