@@ -6,4 +6,4 @@ well as utilities to help in plotting.
 from .pyqt_plotmon import PlotMonitor_pyqt
 from .instrument_monitor import InstrumentMonitor
 
-__all__ = ['PlotMonitor_pyqt', 'InstrumentMonitor']
+__all__ = ["PlotMonitor_pyqt", "InstrumentMonitor"]
