@@ -6,27 +6,25 @@ from quantify.visualization.SI_utilities import SI_val_to_msg_str
 
 
 def test_non_SI():
-    unit = 'arb.unit.'
+    unit = "arb.unit."
     scale_factor, post_unit = SI_prefix_and_scale_factor(val=5, unit=unit)
     assert scale_factor == 1
     assert unit == post_unit
 
 
 def test_SI_scale_factors():
-    unit = 'V'
+    unit = "V"
     scale_factor, post_unit = SI_prefix_and_scale_factor(val=5, unit=unit)
     assert scale_factor == 1
-    assert ''+unit == post_unit
+    assert "" + unit == post_unit
 
-    scale_factor, post_unit = SI_prefix_and_scale_factor(val=5000,
-                                                         unit=unit)
+    scale_factor, post_unit = SI_prefix_and_scale_factor(val=5000, unit=unit)
     assert scale_factor, 1 == 1000
-    assert 'k'+unit == post_unit
+    assert "k" + unit == post_unit
 
-    scale_factor, post_unit = SI_prefix_and_scale_factor(val=0.05,
-                                                         unit=unit)
+    scale_factor, post_unit = SI_prefix_and_scale_factor(val=0.05, unit=unit)
     assert scale_factor == 1000
-    assert 'm'+unit == post_unit
+    assert "m" + unit == post_unit
 
 
 def test_label_scaling():
@@ -37,21 +35,21 @@ def test_label_scaling():
     f, ax = plt.subplots()
     x = np.linspace(-6, 6, 101)
     y = np.cos(x)
-    ax.plot(x*1000, y/1e5)
+    ax.plot(x * 1000, y / 1e5)
 
-    set_xlabel(ax, 'Distance', 'm')
-    set_ylabel(ax, 'Amplitude', 'V')
+    set_xlabel(ax, "Distance", "m")
+    set_ylabel(ax, "Amplitude", "V")
 
     xlab = ax.get_xlabel()
     ylab = ax.get_ylabel()
-    assert xlab == 'Distance (km)'
-    assert ylab == 'Amplitude (μV)'
+    assert xlab == "Distance (km)"
+    assert ylab == "Amplitude (μV)"
 
 
 def test_SI_val_to_msg_str():
-    val, unit = SI_val_to_msg_str(1030, 'm')
+    val, unit = SI_val_to_msg_str(1030, "m")
     assert val == str(1.03)
-    assert unit == 'km'
+    assert unit == "km"
 
 
 # class test_plot_lmfit_res(unittest.TestCase):
